Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterDirectAccessServiceServer(s grpc.ServiceRegistrar, srv DirectAccessServiceServer)
- type AdbMessage
- func (*AdbMessage) Descriptor() ([]byte, []int)deprecated
- func (x *AdbMessage) GetContents() isAdbMessage_Contents
- func (x *AdbMessage) GetOpen() *Open
- func (x *AdbMessage) GetStreamData() *StreamData
- func (*AdbMessage) ProtoMessage()
- func (x *AdbMessage) ProtoReflect() protoreflect.Message
- func (x *AdbMessage) Reset()
- func (x *AdbMessage) String() string
- type AdbMessage_Open
- type AdbMessage_StreamData
- type AndroidDevice
- func (*AndroidDevice) Descriptor() ([]byte, []int)deprecated
- func (x *AndroidDevice) GetAndroidModelId() string
- func (x *AndroidDevice) GetAndroidVersionId() string
- func (x *AndroidDevice) GetLocale() string
- func (x *AndroidDevice) GetOrientation() string
- func (*AndroidDevice) ProtoMessage()
- func (x *AndroidDevice) ProtoReflect() protoreflect.Message
- func (x *AndroidDevice) Reset()
- func (x *AndroidDevice) String() string
- type CancelDeviceSessionRequest
- func (*CancelDeviceSessionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CancelDeviceSessionRequest) GetName() string
- func (*CancelDeviceSessionRequest) ProtoMessage()
- func (x *CancelDeviceSessionRequest) ProtoReflect() protoreflect.Message
- func (x *CancelDeviceSessionRequest) Reset()
- func (x *CancelDeviceSessionRequest) String() string
- type Close
- type CreateDeviceSessionRequest
- func (*CreateDeviceSessionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateDeviceSessionRequest) GetDeviceSession() *DeviceSession
- func (x *CreateDeviceSessionRequest) GetDeviceSessionId() string
- func (x *CreateDeviceSessionRequest) GetParent() string
- func (*CreateDeviceSessionRequest) ProtoMessage()
- func (x *CreateDeviceSessionRequest) ProtoReflect() protoreflect.Message
- func (x *CreateDeviceSessionRequest) Reset()
- func (x *CreateDeviceSessionRequest) String() string
- type DeviceMessage
- func (*DeviceMessage) Descriptor() ([]byte, []int)deprecated
- func (x *DeviceMessage) GetContents() isDeviceMessage_Contents
- func (x *DeviceMessage) GetStatusUpdate() *StatusUpdate
- func (x *DeviceMessage) GetStreamData() *StreamData
- func (x *DeviceMessage) GetStreamStatus() *StreamStatus
- func (*DeviceMessage) ProtoMessage()
- func (x *DeviceMessage) ProtoReflect() protoreflect.Message
- func (x *DeviceMessage) Reset()
- func (x *DeviceMessage) String() string
- type DeviceMessage_StatusUpdate
- type DeviceMessage_StreamData
- type DeviceMessage_StreamStatus
- type DeviceSession
- func (*DeviceSession) Descriptor() ([]byte, []int)deprecated
- func (x *DeviceSession) GetActiveStartTime() *timestamppb.Timestamp
- func (x *DeviceSession) GetAndroidDevice() *AndroidDevice
- func (x *DeviceSession) GetCreateTime() *timestamppb.Timestamp
- func (x *DeviceSession) GetDisplayName() string
- func (x *DeviceSession) GetExpiration() isDeviceSession_Expiration
- func (x *DeviceSession) GetExpireTime() *timestamppb.Timestamp
- func (x *DeviceSession) GetInactivityTimeout() *durationpb.Duration
- func (x *DeviceSession) GetName() string
- func (x *DeviceSession) GetState() DeviceSession_SessionState
- func (x *DeviceSession) GetStateHistories() []*DeviceSession_SessionStateEvent
- func (x *DeviceSession) GetTtl() *durationpb.Duration
- func (*DeviceSession) ProtoMessage()
- func (x *DeviceSession) ProtoReflect() protoreflect.Message
- func (x *DeviceSession) Reset()
- func (x *DeviceSession) String() string
- type DeviceSession_ExpireTime
- type DeviceSession_SessionState
- func (DeviceSession_SessionState) Descriptor() protoreflect.EnumDescriptor
- func (x DeviceSession_SessionState) Enum() *DeviceSession_SessionState
- func (DeviceSession_SessionState) EnumDescriptor() ([]byte, []int)deprecated
- func (x DeviceSession_SessionState) Number() protoreflect.EnumNumber
- func (x DeviceSession_SessionState) String() string
- func (DeviceSession_SessionState) Type() protoreflect.EnumType
- type DeviceSession_SessionStateEvent
- func (*DeviceSession_SessionStateEvent) Descriptor() ([]byte, []int)deprecated
- func (x *DeviceSession_SessionStateEvent) GetEventTime() *timestamppb.Timestamp
- func (x *DeviceSession_SessionStateEvent) GetSessionState() DeviceSession_SessionState
- func (x *DeviceSession_SessionStateEvent) GetStateMessage() string
- func (*DeviceSession_SessionStateEvent) ProtoMessage()
- func (x *DeviceSession_SessionStateEvent) ProtoReflect() protoreflect.Message
- func (x *DeviceSession_SessionStateEvent) Reset()
- func (x *DeviceSession_SessionStateEvent) String() string
- type DeviceSession_Ttl
- type DirectAccessServiceClient
- type DirectAccessServiceServer
- type DirectAccessService_AdbConnectClient
- type DirectAccessService_AdbConnectServer
- type Fail
- type GetDeviceSessionRequest
- func (*GetDeviceSessionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetDeviceSessionRequest) GetName() string
- func (*GetDeviceSessionRequest) ProtoMessage()
- func (x *GetDeviceSessionRequest) ProtoReflect() protoreflect.Message
- func (x *GetDeviceSessionRequest) Reset()
- func (x *GetDeviceSessionRequest) String() string
- type ListDeviceSessionsRequest
- func (*ListDeviceSessionsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ListDeviceSessionsRequest) GetFilter() string
- func (x *ListDeviceSessionsRequest) GetPageSize() int32
- func (x *ListDeviceSessionsRequest) GetPageToken() string
- func (x *ListDeviceSessionsRequest) GetParent() string
- func (*ListDeviceSessionsRequest) ProtoMessage()
- func (x *ListDeviceSessionsRequest) ProtoReflect() protoreflect.Message
- func (x *ListDeviceSessionsRequest) Reset()
- func (x *ListDeviceSessionsRequest) String() string
- type ListDeviceSessionsResponse
- func (*ListDeviceSessionsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListDeviceSessionsResponse) GetDeviceSessions() []*DeviceSession
- func (x *ListDeviceSessionsResponse) GetNextPageToken() string
- func (*ListDeviceSessionsResponse) ProtoMessage()
- func (x *ListDeviceSessionsResponse) ProtoReflect() protoreflect.Message
- func (x *ListDeviceSessionsResponse) Reset()
- func (x *ListDeviceSessionsResponse) String() string
- type Okay
- type Open
- type StatusUpdate
- func (*StatusUpdate) Descriptor() ([]byte, []int)deprecated
- func (x *StatusUpdate) GetFeatures() string
- func (x *StatusUpdate) GetProperties() map[string]string
- func (x *StatusUpdate) GetState() StatusUpdate_DeviceState
- func (*StatusUpdate) ProtoMessage()
- func (x *StatusUpdate) ProtoReflect() protoreflect.Message
- func (x *StatusUpdate) Reset()
- func (x *StatusUpdate) String() string
- type StatusUpdate_DeviceState
- func (StatusUpdate_DeviceState) Descriptor() protoreflect.EnumDescriptor
- func (x StatusUpdate_DeviceState) Enum() *StatusUpdate_DeviceState
- func (StatusUpdate_DeviceState) EnumDescriptor() ([]byte, []int)deprecated
- func (x StatusUpdate_DeviceState) Number() protoreflect.EnumNumber
- func (x StatusUpdate_DeviceState) String() string
- func (StatusUpdate_DeviceState) Type() protoreflect.EnumType
- type StreamData
- func (*StreamData) Descriptor() ([]byte, []int)deprecated
- func (x *StreamData) GetClose() *Close
- func (x *StreamData) GetContents() isStreamData_Contents
- func (x *StreamData) GetData() []byte
- func (x *StreamData) GetStreamId() int32
- func (*StreamData) ProtoMessage()
- func (x *StreamData) ProtoReflect() protoreflect.Message
- func (x *StreamData) Reset()
- func (x *StreamData) String() string
- type StreamData_Close
- type StreamData_Data
- type StreamStatus
- func (*StreamStatus) Descriptor() ([]byte, []int)deprecated
- func (x *StreamStatus) GetFail() *Fail
- func (x *StreamStatus) GetOkay() *Okay
- func (x *StreamStatus) GetStatus() isStreamStatus_Status
- func (x *StreamStatus) GetStreamId() int32
- func (*StreamStatus) ProtoMessage()
- func (x *StreamStatus) ProtoReflect() protoreflect.Message
- func (x *StreamStatus) Reset()
- func (x *StreamStatus) String() string
- type StreamStatus_Fail
- type StreamStatus_Okay
- type UnimplementedDirectAccessServiceServer
- func (UnimplementedDirectAccessServiceServer) AdbConnect(DirectAccessService_AdbConnectServer) error
- func (UnimplementedDirectAccessServiceServer) CancelDeviceSession(context.Context, *CancelDeviceSessionRequest) (*emptypb.Empty, error)
- func (UnimplementedDirectAccessServiceServer) CreateDeviceSession(context.Context, *CreateDeviceSessionRequest) (*DeviceSession, error)
- func (UnimplementedDirectAccessServiceServer) GetDeviceSession(context.Context, *GetDeviceSessionRequest) (*DeviceSession, error)
- func (UnimplementedDirectAccessServiceServer) ListDeviceSessions(context.Context, *ListDeviceSessionsRequest) (*ListDeviceSessionsResponse, error)
- func (UnimplementedDirectAccessServiceServer) UpdateDeviceSession(context.Context, *UpdateDeviceSessionRequest) (*DeviceSession, error)
- type UnsafeDirectAccessServiceServer
- type UpdateDeviceSessionRequest
- func (*UpdateDeviceSessionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateDeviceSessionRequest) GetDeviceSession() *DeviceSession
- func (x *UpdateDeviceSessionRequest) GetUpdateMask() *fieldmaskpb.FieldMask
- func (*UpdateDeviceSessionRequest) ProtoMessage()
- func (x *UpdateDeviceSessionRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateDeviceSessionRequest) Reset()
- func (x *UpdateDeviceSessionRequest) String() string
Constants ¶
const ( DirectAccessService_CreateDeviceSession_FullMethodName = "/google.cloud.devicestreaming.v1.DirectAccessService/CreateDeviceSession" DirectAccessService_ListDeviceSessions_FullMethodName = "/google.cloud.devicestreaming.v1.DirectAccessService/ListDeviceSessions" DirectAccessService_GetDeviceSession_FullMethodName = "/google.cloud.devicestreaming.v1.DirectAccessService/GetDeviceSession" DirectAccessService_CancelDeviceSession_FullMethodName = "/google.cloud.devicestreaming.v1.DirectAccessService/CancelDeviceSession" DirectAccessService_UpdateDeviceSession_FullMethodName = "/google.cloud.devicestreaming.v1.DirectAccessService/UpdateDeviceSession" DirectAccessService_AdbConnect_FullMethodName = "/google.cloud.devicestreaming.v1.DirectAccessService/AdbConnect" )
Variables ¶
var ( StatusUpdate_DeviceState_name = map[int32]string{ 0: "DEVICE_STATE_UNSPECIFIED", 1: "DEVICE", 2: "RECOVERY", 3: "RESCUE", 4: "SIDELOAD", 10: "MISSING", 11: "OFFLINE", 12: "UNAUTHORIZED", 13: "AUTHORIZING", 14: "CONNECTING", } StatusUpdate_DeviceState_value = map[string]int32{ "DEVICE_STATE_UNSPECIFIED": 0, "DEVICE": 1, "RECOVERY": 2, "RESCUE": 3, "SIDELOAD": 4, "MISSING": 10, "OFFLINE": 11, "UNAUTHORIZED": 12, "AUTHORIZING": 13, "CONNECTING": 14, } )
Enum value maps for StatusUpdate_DeviceState.
var ( DeviceSession_SessionState_name = map[int32]string{ 0: "SESSION_STATE_UNSPECIFIED", 1: "REQUESTED", 2: "PENDING", 3: "ACTIVE", 4: "EXPIRED", 5: "FINISHED", 6: "UNAVAILABLE", 7: "ERROR", } DeviceSession_SessionState_value = map[string]int32{ "SESSION_STATE_UNSPECIFIED": 0, "REQUESTED": 1, "PENDING": 2, "ACTIVE": 3, "EXPIRED": 4, "FINISHED": 5, "UNAVAILABLE": 6, "ERROR": 7, } )
Enum value maps for DeviceSession_SessionState.
var DirectAccessService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "google.cloud.devicestreaming.v1.DirectAccessService", HandlerType: (*DirectAccessServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "CreateDeviceSession", Handler: _DirectAccessService_CreateDeviceSession_Handler, }, { MethodName: "ListDeviceSessions", Handler: _DirectAccessService_ListDeviceSessions_Handler, }, { MethodName: "GetDeviceSession", Handler: _DirectAccessService_GetDeviceSession_Handler, }, { MethodName: "CancelDeviceSession", Handler: _DirectAccessService_CancelDeviceSession_Handler, }, { MethodName: "UpdateDeviceSession", Handler: _DirectAccessService_UpdateDeviceSession_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "AdbConnect", Handler: _DirectAccessService_AdbConnect_Handler, ServerStreams: true, ClientStreams: true, }, }, Metadata: "google/cloud/devicestreaming/v1/service.proto", }
DirectAccessService_ServiceDesc is the grpc.ServiceDesc for DirectAccessService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_google_cloud_devicestreaming_v1_adb_service_proto protoreflect.FileDescriptor
var File_google_cloud_devicestreaming_v1_service_proto protoreflect.FileDescriptor
Functions ¶
func RegisterDirectAccessServiceServer ¶
func RegisterDirectAccessServiceServer(s grpc.ServiceRegistrar, srv DirectAccessServiceServer)
Types ¶
type AdbMessage ¶
type AdbMessage struct {
// Types that are valid to be assigned to Contents:
//
// *AdbMessage_Open
// *AdbMessage_StreamData
Contents isAdbMessage_Contents `protobuf_oneof:"contents"`
// contains filtered or unexported fields
}
A message to an ADB server.
func (*AdbMessage) Descriptor
deprecated
func (*AdbMessage) Descriptor() ([]byte, []int)
Deprecated: Use AdbMessage.ProtoReflect.Descriptor instead.
func (*AdbMessage) GetContents ¶
func (x *AdbMessage) GetContents() isAdbMessage_Contents
func (*AdbMessage) GetOpen ¶
func (x *AdbMessage) GetOpen() *Open
func (*AdbMessage) GetStreamData ¶
func (x *AdbMessage) GetStreamData() *StreamData
func (*AdbMessage) ProtoMessage ¶
func (*AdbMessage) ProtoMessage()
func (*AdbMessage) ProtoReflect ¶
func (x *AdbMessage) ProtoReflect() protoreflect.Message
func (*AdbMessage) Reset ¶
func (x *AdbMessage) Reset()
func (*AdbMessage) String ¶
func (x *AdbMessage) String() string
type AdbMessage_Open ¶
type AdbMessage_Open struct {
// Open a new stream.
Open *Open `protobuf:"bytes,1,opt,name=open,proto3,oneof"`
}
type AdbMessage_StreamData ¶
type AdbMessage_StreamData struct {
// Send data to a stream.
StreamData *StreamData `protobuf:"bytes,2,opt,name=stream_data,json=streamData,proto3,oneof"`
}
type AndroidDevice ¶
type AndroidDevice struct {
// Required. The id of the Android device to be used.
// Use the TestEnvironmentDiscoveryService to get supported options.
AndroidModelId string `protobuf:"bytes,1,opt,name=android_model_id,json=androidModelId,proto3" json:"android_model_id,omitempty"`
// Required. The id of the Android OS version to be used.
// Use the TestEnvironmentDiscoveryService to get supported options.
AndroidVersionId string `protobuf:"bytes,2,opt,name=android_version_id,json=androidVersionId,proto3" json:"android_version_id,omitempty"`
// Optional. The locale the test device used for testing.
// Use the TestEnvironmentDiscoveryService to get supported options.
Locale string `protobuf:"bytes,3,opt,name=locale,proto3" json:"locale,omitempty"`
// Optional. How the device is oriented during the test.
// Use the TestEnvironmentDiscoveryService to get supported options.
Orientation string `protobuf:"bytes,4,opt,name=orientation,proto3" json:"orientation,omitempty"`
// contains filtered or unexported fields
}
A single Android device.
func (*AndroidDevice) Descriptor
deprecated
func (*AndroidDevice) Descriptor() ([]byte, []int)
Deprecated: Use AndroidDevice.ProtoReflect.Descriptor instead.
func (*AndroidDevice) GetAndroidModelId ¶
func (x *AndroidDevice) GetAndroidModelId() string
func (*AndroidDevice) GetAndroidVersionId ¶
func (x *AndroidDevice) GetAndroidVersionId() string
func (*AndroidDevice) GetLocale ¶
func (x *AndroidDevice) GetLocale() string
func (*AndroidDevice) GetOrientation ¶
func (x *AndroidDevice) GetOrientation() string
func (*AndroidDevice) ProtoMessage ¶
func (*AndroidDevice) ProtoMessage()
func (*AndroidDevice) ProtoReflect ¶
func (x *AndroidDevice) ProtoReflect() protoreflect.Message
func (*AndroidDevice) Reset ¶
func (x *AndroidDevice) Reset()
func (*AndroidDevice) String ¶
func (x *AndroidDevice) String() string
type CancelDeviceSessionRequest ¶
type CancelDeviceSessionRequest struct {
// Required. Name of the DeviceSession, e.g.
// "projects/{project_id}/deviceSessions/{session_id}"
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
Request message for DirectAccessService.CancelDeviceSession.
func (*CancelDeviceSessionRequest) Descriptor
deprecated
func (*CancelDeviceSessionRequest) Descriptor() ([]byte, []int)
Deprecated: Use CancelDeviceSessionRequest.ProtoReflect.Descriptor instead.
func (*CancelDeviceSessionRequest) GetName ¶
func (x *CancelDeviceSessionRequest) GetName() string
func (*CancelDeviceSessionRequest) ProtoMessage ¶
func (*CancelDeviceSessionRequest) ProtoMessage()
func (*CancelDeviceSessionRequest) ProtoReflect ¶
func (x *CancelDeviceSessionRequest) ProtoReflect() protoreflect.Message
func (*CancelDeviceSessionRequest) Reset ¶
func (x *CancelDeviceSessionRequest) Reset()
func (*CancelDeviceSessionRequest) String ¶
func (x *CancelDeviceSessionRequest) String() string
type Close ¶
type Close struct {
// contains filtered or unexported fields
}
Message signifying that the stream closed.
func (*Close) Descriptor
deprecated
func (*Close) ProtoMessage ¶
func (*Close) ProtoMessage()
func (*Close) ProtoReflect ¶
func (x *Close) ProtoReflect() protoreflect.Message
type CreateDeviceSessionRequest ¶
type CreateDeviceSessionRequest struct {
// Required. The Compute Engine project under which this device will be
// allocated. "projects/{project_id}"
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// Required. A DeviceSession to create.
DeviceSession *DeviceSession `protobuf:"bytes,2,opt,name=device_session,json=deviceSession,proto3" json:"device_session,omitempty"`
// Optional. The ID to use for the DeviceSession, which will become the final
// component of the DeviceSession's resource name.
//
// This value should be 4-63 characters, and valid characters
// are /[a-z][0-9]-/.
DeviceSessionId string `protobuf:"bytes,4,opt,name=device_session_id,json=deviceSessionId,proto3" json:"device_session_id,omitempty"`
// contains filtered or unexported fields
}
Request message for DirectAccessService.CreateDeviceSession.
func (*CreateDeviceSessionRequest) Descriptor
deprecated
func (*CreateDeviceSessionRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateDeviceSessionRequest.ProtoReflect.Descriptor instead.
func (*CreateDeviceSessionRequest) GetDeviceSession ¶
func (x *CreateDeviceSessionRequest) GetDeviceSession() *DeviceSession
func (*CreateDeviceSessionRequest) GetDeviceSessionId ¶
func (x *CreateDeviceSessionRequest) GetDeviceSessionId() string
func (*CreateDeviceSessionRequest) GetParent ¶
func (x *CreateDeviceSessionRequest) GetParent() string
func (*CreateDeviceSessionRequest) ProtoMessage ¶
func (*CreateDeviceSessionRequest) ProtoMessage()
func (*CreateDeviceSessionRequest) ProtoReflect ¶
func (x *CreateDeviceSessionRequest) ProtoReflect() protoreflect.Message
func (*CreateDeviceSessionRequest) Reset ¶
func (x *CreateDeviceSessionRequest) Reset()
func (*CreateDeviceSessionRequest) String ¶
func (x *CreateDeviceSessionRequest) String() string
type DeviceMessage ¶
type DeviceMessage struct {
// Types that are valid to be assigned to Contents:
//
// *DeviceMessage_StatusUpdate
// *DeviceMessage_StreamStatus
// *DeviceMessage_StreamData
Contents isDeviceMessage_Contents `protobuf_oneof:"contents"`
// contains filtered or unexported fields
}
A message returned from a device.
func (*DeviceMessage) Descriptor
deprecated
func (*DeviceMessage) Descriptor() ([]byte, []int)
Deprecated: Use DeviceMessage.ProtoReflect.Descriptor instead.
func (*DeviceMessage) GetContents ¶
func (x *DeviceMessage) GetContents() isDeviceMessage_Contents
func (*DeviceMessage) GetStatusUpdate ¶
func (x *DeviceMessage) GetStatusUpdate() *StatusUpdate
func (*DeviceMessage) GetStreamData ¶
func (x *DeviceMessage) GetStreamData() *StreamData
func (*DeviceMessage) GetStreamStatus ¶
func (x *DeviceMessage) GetStreamStatus() *StreamStatus
func (*DeviceMessage) ProtoMessage ¶
func (*DeviceMessage) ProtoMessage()
func (*DeviceMessage) ProtoReflect ¶
func (x *DeviceMessage) ProtoReflect() protoreflect.Message
func (*DeviceMessage) Reset ¶
func (x *DeviceMessage) Reset()
func (*DeviceMessage) String ¶
func (x *DeviceMessage) String() string
type DeviceMessage_StatusUpdate ¶
type DeviceMessage_StatusUpdate struct {
// Information about the device's state.
StatusUpdate *StatusUpdate `protobuf:"bytes,1,opt,name=status_update,json=statusUpdate,proto3,oneof"`
}
type DeviceMessage_StreamData ¶
type DeviceMessage_StreamData struct {
// Data from an open stream.
StreamData *StreamData `protobuf:"bytes,3,opt,name=stream_data,json=streamData,proto3,oneof"`
}
type DeviceMessage_StreamStatus ¶
type DeviceMessage_StreamStatus struct {
// The result of a device stream from ADB.
StreamStatus *StreamStatus `protobuf:"bytes,2,opt,name=stream_status,json=streamStatus,proto3,oneof"`
}
type DeviceSession ¶
type DeviceSession struct {
// Optional. Name of the DeviceSession, e.g.
// "projects/{project_id}/deviceSessions/{session_id}"
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Output only. The title of the DeviceSession to be presented in the UI.
DisplayName string `protobuf:"bytes,2,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
// Output only. Current state of the DeviceSession.
State DeviceSession_SessionState `` /* 128-byte string literal not displayed */
// Output only. The historical state transitions of the session_state message
// including the current session state.
StateHistories []*DeviceSession_SessionStateEvent `protobuf:"bytes,14,rep,name=state_histories,json=stateHistories,proto3" json:"state_histories,omitempty"`
// The amount of time that a device will be initially allocated for.
//
// Types that are valid to be assigned to Expiration:
//
// *DeviceSession_Ttl
// *DeviceSession_ExpireTime
Expiration isDeviceSession_Expiration `protobuf_oneof:"expiration"`
// Output only. The interval of time that this device must be interacted with
// before it transitions from ACTIVE to TIMEOUT_INACTIVITY.
InactivityTimeout *durationpb.Duration `protobuf:"bytes,7,opt,name=inactivity_timeout,json=inactivityTimeout,proto3" json:"inactivity_timeout,omitempty"`
// Output only. The time that the Session was created.
CreateTime *timestamppb.Timestamp `protobuf:"bytes,8,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
// Output only. The timestamp that the session first became ACTIVE.
ActiveStartTime *timestamppb.Timestamp `protobuf:"bytes,9,opt,name=active_start_time,json=activeStartTime,proto3" json:"active_start_time,omitempty"`
// Required. The requested device
AndroidDevice *AndroidDevice `protobuf:"bytes,15,opt,name=android_device,json=androidDevice,proto3" json:"android_device,omitempty"`
// contains filtered or unexported fields
}
Protobuf message describing the device message, used from several RPCs.
func (*DeviceSession) Descriptor
deprecated
func (*DeviceSession) Descriptor() ([]byte, []int)
Deprecated: Use DeviceSession.ProtoReflect.Descriptor instead.
func (*DeviceSession) GetActiveStartTime ¶
func (x *DeviceSession) GetActiveStartTime() *timestamppb.Timestamp
func (*DeviceSession) GetAndroidDevice ¶
func (x *DeviceSession) GetAndroidDevice() *AndroidDevice
func (*DeviceSession) GetCreateTime ¶
func (x *DeviceSession) GetCreateTime() *timestamppb.Timestamp
func (*DeviceSession) GetDisplayName ¶
func (x *DeviceSession) GetDisplayName() string
func (*DeviceSession) GetExpiration ¶
func (x *DeviceSession) GetExpiration() isDeviceSession_Expiration
func (*DeviceSession) GetExpireTime ¶
func (x *DeviceSession) GetExpireTime() *timestamppb.Timestamp
func (*DeviceSession) GetInactivityTimeout ¶
func (x *DeviceSession) GetInactivityTimeout() *durationpb.Duration
func (*DeviceSession) GetName ¶
func (x *DeviceSession) GetName() string
func (*DeviceSession) GetState ¶
func (x *DeviceSession) GetState() DeviceSession_SessionState
func (*DeviceSession) GetStateHistories ¶
func (x *DeviceSession) GetStateHistories() []*DeviceSession_SessionStateEvent
func (*DeviceSession) GetTtl ¶
func (x *DeviceSession) GetTtl() *durationpb.Duration
func (*DeviceSession) ProtoMessage ¶
func (*DeviceSession) ProtoMessage()
func (*DeviceSession) ProtoReflect ¶
func (x *DeviceSession) ProtoReflect() protoreflect.Message
func (*DeviceSession) Reset ¶
func (x *DeviceSession) Reset()
func (*DeviceSession) String ¶
func (x *DeviceSession) String() string
type DeviceSession_ExpireTime ¶
type DeviceSession_ExpireTime struct {
// Optional. If the device is still in use at this time, any connections
// will be ended and the SessionState will transition from ACTIVE to
// FINISHED.
ExpireTime *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=expire_time,json=expireTime,proto3,oneof"`
}
type DeviceSession_SessionState ¶
type DeviceSession_SessionState int32
The state that the DeviceSession resides.
const ( // Default value. This value is unused. DeviceSession_SESSION_STATE_UNSPECIFIED DeviceSession_SessionState = 0 // Initial state of a session request. The session is being validated for // correctness and a device is not yet requested. DeviceSession_REQUESTED DeviceSession_SessionState = 1 // The session has been validated and is in the queue for a device. DeviceSession_PENDING DeviceSession_SessionState = 2 // The session has been granted and the device is accepting // connections. DeviceSession_ACTIVE DeviceSession_SessionState = 3 // The session duration exceeded the device's reservation time period and // timed out automatically. DeviceSession_EXPIRED DeviceSession_SessionState = 4 // The user is finished with the session and it was canceled by the user // while the request was still getting allocated or after allocation and // during device usage period. DeviceSession_FINISHED DeviceSession_SessionState = 5 // Unable to complete the session because the device was unavailable and // it failed to allocate through the scheduler. For example, a device not // in the catalog was requested or the request expired in the allocation // queue. DeviceSession_UNAVAILABLE DeviceSession_SessionState = 6 // Unable to complete the session for an internal reason, such as an // infrastructure failure. DeviceSession_ERROR DeviceSession_SessionState = 7 )
func (DeviceSession_SessionState) Descriptor ¶
func (DeviceSession_SessionState) Descriptor() protoreflect.EnumDescriptor
func (DeviceSession_SessionState) Enum ¶
func (x DeviceSession_SessionState) Enum() *DeviceSession_SessionState
func (DeviceSession_SessionState) EnumDescriptor
deprecated
func (DeviceSession_SessionState) EnumDescriptor() ([]byte, []int)
Deprecated: Use DeviceSession_SessionState.Descriptor instead.
func (DeviceSession_SessionState) Number ¶
func (x DeviceSession_SessionState) Number() protoreflect.EnumNumber
func (DeviceSession_SessionState) String ¶
func (x DeviceSession_SessionState) String() string
func (DeviceSession_SessionState) Type ¶
func (DeviceSession_SessionState) Type() protoreflect.EnumType
type DeviceSession_SessionStateEvent ¶
type DeviceSession_SessionStateEvent struct {
// Output only. The session_state tracked by this event
SessionState DeviceSession_SessionState `` /* 162-byte string literal not displayed */
// Output only. The time that the session_state first encountered that
// state.
EventTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=event_time,json=eventTime,proto3" json:"event_time,omitempty"`
// Output only. A human-readable message to explain the state.
StateMessage string `protobuf:"bytes,3,opt,name=state_message,json=stateMessage,proto3" json:"state_message,omitempty"`
// contains filtered or unexported fields
}
A message encapsulating a series of Session states and the time that the DeviceSession first entered those states.
func (*DeviceSession_SessionStateEvent) Descriptor
deprecated
func (*DeviceSession_SessionStateEvent) Descriptor() ([]byte, []int)
Deprecated: Use DeviceSession_SessionStateEvent.ProtoReflect.Descriptor instead.
func (*DeviceSession_SessionStateEvent) GetEventTime ¶
func (x *DeviceSession_SessionStateEvent) GetEventTime() *timestamppb.Timestamp
func (*DeviceSession_SessionStateEvent) GetSessionState ¶
func (x *DeviceSession_SessionStateEvent) GetSessionState() DeviceSession_SessionState
func (*DeviceSession_SessionStateEvent) GetStateMessage ¶
func (x *DeviceSession_SessionStateEvent) GetStateMessage() string
func (*DeviceSession_SessionStateEvent) ProtoMessage ¶
func (*DeviceSession_SessionStateEvent) ProtoMessage()
func (*DeviceSession_SessionStateEvent) ProtoReflect ¶
func (x *DeviceSession_SessionStateEvent) ProtoReflect() protoreflect.Message
func (*DeviceSession_SessionStateEvent) Reset ¶
func (x *DeviceSession_SessionStateEvent) Reset()
func (*DeviceSession_SessionStateEvent) String ¶
func (x *DeviceSession_SessionStateEvent) String() string
type DeviceSession_Ttl ¶
type DeviceSession_Ttl struct {
// Optional. The amount of time that a device will be initially allocated
// for. This can eventually be extended with the UpdateDeviceSession RPC.
// Default: 15 minutes.
Ttl *durationpb.Duration `protobuf:"bytes,13,opt,name=ttl,proto3,oneof"`
}
type DirectAccessServiceClient ¶
type DirectAccessServiceClient interface {
// Creates a DeviceSession.
CreateDeviceSession(ctx context.Context, in *CreateDeviceSessionRequest, opts ...grpc.CallOption) (*DeviceSession, error)
// Lists DeviceSessions owned by the project user.
ListDeviceSessions(ctx context.Context, in *ListDeviceSessionsRequest, opts ...grpc.CallOption) (*ListDeviceSessionsResponse, error)
// Gets a DeviceSession, which documents the allocation status and
// whether the device is allocated. Clients making requests from this API
// must poll GetDeviceSession.
GetDeviceSession(ctx context.Context, in *GetDeviceSessionRequest, opts ...grpc.CallOption) (*DeviceSession, error)
// Cancel a DeviceSession.
// This RPC changes the DeviceSession to state FINISHED and terminates all
// connections.
// Canceled sessions are not deleted and can be retrieved or
// listed by the user until they expire based on the 28 day deletion policy.
CancelDeviceSession(ctx context.Context, in *CancelDeviceSessionRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
// Updates the current DeviceSession to the fields described by the
// update_mask.
UpdateDeviceSession(ctx context.Context, in *UpdateDeviceSessionRequest, opts ...grpc.CallOption) (*DeviceSession, error)
// Exposes an ADB connection if the device supports ADB.
// gRPC headers are used to authenticate the Connect RPC, as well as
// associate to a particular DeviceSession.
// In particular, the user must specify the "X-Omnilab-Session-Name" header.
AdbConnect(ctx context.Context, opts ...grpc.CallOption) (DirectAccessService_AdbConnectClient, error)
}
DirectAccessServiceClient is the client API for DirectAccessService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewDirectAccessServiceClient ¶
func NewDirectAccessServiceClient(cc grpc.ClientConnInterface) DirectAccessServiceClient
type DirectAccessServiceServer ¶
type DirectAccessServiceServer interface {
// Creates a DeviceSession.
CreateDeviceSession(context.Context, *CreateDeviceSessionRequest) (*DeviceSession, error)
// Lists DeviceSessions owned by the project user.
ListDeviceSessions(context.Context, *ListDeviceSessionsRequest) (*ListDeviceSessionsResponse, error)
// Gets a DeviceSession, which documents the allocation status and
// whether the device is allocated. Clients making requests from this API
// must poll GetDeviceSession.
GetDeviceSession(context.Context, *GetDeviceSessionRequest) (*DeviceSession, error)
// Cancel a DeviceSession.
// This RPC changes the DeviceSession to state FINISHED and terminates all
// connections.
// Canceled sessions are not deleted and can be retrieved or
// listed by the user until they expire based on the 28 day deletion policy.
CancelDeviceSession(context.Context, *CancelDeviceSessionRequest) (*emptypb.Empty, error)
// Updates the current DeviceSession to the fields described by the
// update_mask.
UpdateDeviceSession(context.Context, *UpdateDeviceSessionRequest) (*DeviceSession, error)
// Exposes an ADB connection if the device supports ADB.
// gRPC headers are used to authenticate the Connect RPC, as well as
// associate to a particular DeviceSession.
// In particular, the user must specify the "X-Omnilab-Session-Name" header.
AdbConnect(DirectAccessService_AdbConnectServer) error
}
DirectAccessServiceServer is the server API for DirectAccessService service. All implementations should embed UnimplementedDirectAccessServiceServer for forward compatibility
type DirectAccessService_AdbConnectClient ¶
type DirectAccessService_AdbConnectClient interface {
Send(*AdbMessage) error
Recv() (*DeviceMessage, error)
grpc.ClientStream
}
type DirectAccessService_AdbConnectServer ¶
type DirectAccessService_AdbConnectServer interface {
Send(*DeviceMessage) error
Recv() (*AdbMessage, error)
grpc.ServerStream
}
type Fail ¶
type Fail struct {
// A user-displayable failure reason.
Reason string `protobuf:"bytes,1,opt,name=reason,proto3" json:"reason,omitempty"`
// contains filtered or unexported fields
}
Message signifying that the stream failed to open
func (*Fail) Descriptor
deprecated
func (*Fail) ProtoMessage ¶
func (*Fail) ProtoMessage()
func (*Fail) ProtoReflect ¶
func (x *Fail) ProtoReflect() protoreflect.Message
type GetDeviceSessionRequest ¶
type GetDeviceSessionRequest struct {
// Required. Name of the DeviceSession, e.g.
// "projects/{project_id}/deviceSessions/{session_id}"
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
Request message for DirectAccessService.GetDeviceSession.
func (*GetDeviceSessionRequest) Descriptor
deprecated
func (*GetDeviceSessionRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetDeviceSessionRequest.ProtoReflect.Descriptor instead.
func (*GetDeviceSessionRequest) GetName ¶
func (x *GetDeviceSessionRequest) GetName() string
func (*GetDeviceSessionRequest) ProtoMessage ¶
func (*GetDeviceSessionRequest) ProtoMessage()
func (*GetDeviceSessionRequest) ProtoReflect ¶
func (x *GetDeviceSessionRequest) ProtoReflect() protoreflect.Message
func (*GetDeviceSessionRequest) Reset ¶
func (x *GetDeviceSessionRequest) Reset()
func (*GetDeviceSessionRequest) String ¶
func (x *GetDeviceSessionRequest) String() string
type ListDeviceSessionsRequest ¶
type ListDeviceSessionsRequest struct {
// Required. The name of the parent to request, e.g. "projects/{project_id}"
Parent string `protobuf:"bytes,4,opt,name=parent,proto3" json:"parent,omitempty"`
// Optional. The maximum number of DeviceSessions to return.
PageSize int32 `protobuf:"varint,1,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
// Optional. A continuation token for paging.
PageToken string `protobuf:"bytes,2,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
// Optional. If specified, responses will be filtered by the given filter.
// Allowed fields are: session_state.
Filter string `protobuf:"bytes,3,opt,name=filter,proto3" json:"filter,omitempty"`
// contains filtered or unexported fields
}
Request message for DirectAccessService.ListDeviceSessions.
func (*ListDeviceSessionsRequest) Descriptor
deprecated
func (*ListDeviceSessionsRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListDeviceSessionsRequest.ProtoReflect.Descriptor instead.
func (*ListDeviceSessionsRequest) GetFilter ¶
func (x *ListDeviceSessionsRequest) GetFilter() string
func (*ListDeviceSessionsRequest) GetPageSize ¶
func (x *ListDeviceSessionsRequest) GetPageSize() int32
func (*ListDeviceSessionsRequest) GetPageToken ¶
func (x *ListDeviceSessionsRequest) GetPageToken() string
func (*ListDeviceSessionsRequest) GetParent ¶
func (x *ListDeviceSessionsRequest) GetParent() string
func (*ListDeviceSessionsRequest) ProtoMessage ¶
func (*ListDeviceSessionsRequest) ProtoMessage()
func (*ListDeviceSessionsRequest) ProtoReflect ¶
func (x *ListDeviceSessionsRequest) ProtoReflect() protoreflect.Message
func (*ListDeviceSessionsRequest) Reset ¶
func (x *ListDeviceSessionsRequest) Reset()
func (*ListDeviceSessionsRequest) String ¶
func (x *ListDeviceSessionsRequest) String() string
type ListDeviceSessionsResponse ¶
type ListDeviceSessionsResponse struct {
// The sessions matching the specified filter in the given cloud project.
DeviceSessions []*DeviceSession `protobuf:"bytes,1,rep,name=device_sessions,json=deviceSessions,proto3" json:"device_sessions,omitempty"`
// A token, which can be sent as `page_token` to retrieve the next page.
// If this field is omitted, there are no subsequent pages.
NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
// contains filtered or unexported fields
}
Response message for DirectAccessService.ListDeviceSessions.
func (*ListDeviceSessionsResponse) Descriptor
deprecated
func (*ListDeviceSessionsResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListDeviceSessionsResponse.ProtoReflect.Descriptor instead.
func (*ListDeviceSessionsResponse) GetDeviceSessions ¶
func (x *ListDeviceSessionsResponse) GetDeviceSessions() []*DeviceSession
func (*ListDeviceSessionsResponse) GetNextPageToken ¶
func (x *ListDeviceSessionsResponse) GetNextPageToken() string
func (*ListDeviceSessionsResponse) ProtoMessage ¶
func (*ListDeviceSessionsResponse) ProtoMessage()
func (*ListDeviceSessionsResponse) ProtoReflect ¶
func (x *ListDeviceSessionsResponse) ProtoReflect() protoreflect.Message
func (*ListDeviceSessionsResponse) Reset ¶
func (x *ListDeviceSessionsResponse) Reset()
func (*ListDeviceSessionsResponse) String ¶
func (x *ListDeviceSessionsResponse) String() string
type Okay ¶
type Okay struct {
// contains filtered or unexported fields
}
Message signifying that the stream is open
func (*Okay) Descriptor
deprecated
func (*Okay) ProtoMessage ¶
func (*Okay) ProtoMessage()
func (*Okay) ProtoReflect ¶
func (x *Okay) ProtoReflect() protoreflect.Message
type Open ¶
type Open struct {
// Required. The unique ID that will be used to talk to this stream. This
// should probably just be a number that increments for each new Open request.
StreamId int32 `protobuf:"varint,1,opt,name=stream_id,json=streamId,proto3" json:"stream_id,omitempty"`
// Optional. An ADB service to use in the new stream.
Service string `protobuf:"bytes,2,opt,name=service,proto3" json:"service,omitempty"`
// contains filtered or unexported fields
}
Message for opening a new stream.
func (*Open) Descriptor
deprecated
func (*Open) GetService ¶
func (*Open) GetStreamId ¶
func (*Open) ProtoMessage ¶
func (*Open) ProtoMessage()
func (*Open) ProtoReflect ¶
func (x *Open) ProtoReflect() protoreflect.Message
type StatusUpdate ¶
type StatusUpdate struct {
// The device's state
State StatusUpdate_DeviceState `` /* 126-byte string literal not displayed */
// A map of properties with information about this device.
Properties map[string]string `` /* 147-byte string literal not displayed */
// A comma-separated list of "features" that this device supports.
Features string `protobuf:"bytes,3,opt,name=features,proto3" json:"features,omitempty"`
// contains filtered or unexported fields
}
A StatusUpdate message given over the ADB protocol for the device state.
func (*StatusUpdate) Descriptor
deprecated
func (*StatusUpdate) Descriptor() ([]byte, []int)
Deprecated: Use StatusUpdate.ProtoReflect.Descriptor instead.
func (*StatusUpdate) GetFeatures ¶
func (x *StatusUpdate) GetFeatures() string
func (*StatusUpdate) GetProperties ¶
func (x *StatusUpdate) GetProperties() map[string]string
func (*StatusUpdate) GetState ¶
func (x *StatusUpdate) GetState() StatusUpdate_DeviceState
func (*StatusUpdate) ProtoMessage ¶
func (*StatusUpdate) ProtoMessage()
func (*StatusUpdate) ProtoReflect ¶
func (x *StatusUpdate) ProtoReflect() protoreflect.Message
func (*StatusUpdate) Reset ¶
func (x *StatusUpdate) Reset()
func (*StatusUpdate) String ¶
func (x *StatusUpdate) String() string
type StatusUpdate_DeviceState ¶
type StatusUpdate_DeviceState int32
The state displayed with the ADB Device when running "adb devices"
const ( // The device state is unknown. StatusUpdate_DEVICE_STATE_UNSPECIFIED StatusUpdate_DeviceState = 0 // The ADB device is in the "device" status. StatusUpdate_DEVICE StatusUpdate_DeviceState = 1 // The ADB device is in the "recovery" status. StatusUpdate_RECOVERY StatusUpdate_DeviceState = 2 // The ADB device is in the "rescue" status. StatusUpdate_RESCUE StatusUpdate_DeviceState = 3 // The ADB device is in the "sideload" status. StatusUpdate_SIDELOAD StatusUpdate_DeviceState = 4 // The ADB device is in the "missing" status. StatusUpdate_MISSING StatusUpdate_DeviceState = 10 // The ADB device is in the "offline" status. StatusUpdate_OFFLINE StatusUpdate_DeviceState = 11 // The ADB device is in the "unauthorized" status. StatusUpdate_UNAUTHORIZED StatusUpdate_DeviceState = 12 // The ADB device is in the "authorizing" status. StatusUpdate_AUTHORIZING StatusUpdate_DeviceState = 13 // The ADB device is in the "connecting" status. StatusUpdate_CONNECTING StatusUpdate_DeviceState = 14 )
func (StatusUpdate_DeviceState) Descriptor ¶
func (StatusUpdate_DeviceState) Descriptor() protoreflect.EnumDescriptor
func (StatusUpdate_DeviceState) Enum ¶
func (x StatusUpdate_DeviceState) Enum() *StatusUpdate_DeviceState
func (StatusUpdate_DeviceState) EnumDescriptor
deprecated
func (StatusUpdate_DeviceState) EnumDescriptor() ([]byte, []int)
Deprecated: Use StatusUpdate_DeviceState.Descriptor instead.
func (StatusUpdate_DeviceState) Number ¶
func (x StatusUpdate_DeviceState) Number() protoreflect.EnumNumber
func (StatusUpdate_DeviceState) String ¶
func (x StatusUpdate_DeviceState) String() string
func (StatusUpdate_DeviceState) Type ¶
func (StatusUpdate_DeviceState) Type() protoreflect.EnumType
type StreamData ¶
type StreamData struct {
// Required. The unique ID of this stream, assigned by the client.
StreamId int32 `protobuf:"varint,1,opt,name=stream_id,json=streamId,proto3" json:"stream_id,omitempty"`
// The data of the stream, either bytes or "Close", indicating that the stream
// is done.
//
// Types that are valid to be assigned to Contents:
//
// *StreamData_Data
// *StreamData_Close
Contents isStreamData_Contents `protobuf_oneof:"contents"`
// contains filtered or unexported fields
}
Data for a stream.
func (*StreamData) Descriptor
deprecated
func (*StreamData) Descriptor() ([]byte, []int)
Deprecated: Use StreamData.ProtoReflect.Descriptor instead.
func (*StreamData) GetClose ¶
func (x *StreamData) GetClose() *Close
func (*StreamData) GetContents ¶
func (x *StreamData) GetContents() isStreamData_Contents
func (*StreamData) GetData ¶
func (x *StreamData) GetData() []byte
func (*StreamData) GetStreamId ¶
func (x *StreamData) GetStreamId() int32
func (*StreamData) ProtoMessage ¶
func (*StreamData) ProtoMessage()
func (*StreamData) ProtoReflect ¶
func (x *StreamData) ProtoReflect() protoreflect.Message
func (*StreamData) Reset ¶
func (x *StreamData) Reset()
func (*StreamData) String ¶
func (x *StreamData) String() string
type StreamData_Close ¶
type StreamData_Close struct {
// The stream is closing. EOF.
Close *Close `protobuf:"bytes,3,opt,name=close,proto3,oneof"`
}
type StreamData_Data ¶
type StreamData_Data struct {
// Data in the stream.
Data []byte `protobuf:"bytes,2,opt,name=data,proto3,oneof"`
}
type StreamStatus ¶
type StreamStatus struct {
// The unique ID of this stream, assigned by the client.
StreamId int32 `protobuf:"varint,1,opt,name=stream_id,json=streamId,proto3" json:"stream_id,omitempty"`
// The result of the stream. Either "Okay" for success or "Fail" for failure.
//
// Types that are valid to be assigned to Status:
//
// *StreamStatus_Okay
// *StreamStatus_Fail
Status isStreamStatus_Status `protobuf_oneof:"status"`
// contains filtered or unexported fields
}
The result of a stream.
func (*StreamStatus) Descriptor
deprecated
func (*StreamStatus) Descriptor() ([]byte, []int)
Deprecated: Use StreamStatus.ProtoReflect.Descriptor instead.
func (*StreamStatus) GetFail ¶
func (x *StreamStatus) GetFail() *Fail
func (*StreamStatus) GetOkay ¶
func (x *StreamStatus) GetOkay() *Okay
func (*StreamStatus) GetStatus ¶
func (x *StreamStatus) GetStatus() isStreamStatus_Status
func (*StreamStatus) GetStreamId ¶
func (x *StreamStatus) GetStreamId() int32
func (*StreamStatus) ProtoMessage ¶
func (*StreamStatus) ProtoMessage()
func (*StreamStatus) ProtoReflect ¶
func (x *StreamStatus) ProtoReflect() protoreflect.Message
func (*StreamStatus) Reset ¶
func (x *StreamStatus) Reset()
func (*StreamStatus) String ¶
func (x *StreamStatus) String() string
type StreamStatus_Fail ¶
type StreamStatus_Fail struct {
// Fail for failure.
Fail *Fail `protobuf:"bytes,3,opt,name=fail,proto3,oneof"`
}
type StreamStatus_Okay ¶
type StreamStatus_Okay struct {
// Okay for success.
Okay *Okay `protobuf:"bytes,2,opt,name=okay,proto3,oneof"`
}
type UnimplementedDirectAccessServiceServer ¶
type UnimplementedDirectAccessServiceServer struct {
}
UnimplementedDirectAccessServiceServer should be embedded to have forward compatible implementations.
func (UnimplementedDirectAccessServiceServer) AdbConnect ¶
func (UnimplementedDirectAccessServiceServer) AdbConnect(DirectAccessService_AdbConnectServer) error
func (UnimplementedDirectAccessServiceServer) CancelDeviceSession ¶
func (UnimplementedDirectAccessServiceServer) CancelDeviceSession(context.Context, *CancelDeviceSessionRequest) (*emptypb.Empty, error)
func (UnimplementedDirectAccessServiceServer) CreateDeviceSession ¶
func (UnimplementedDirectAccessServiceServer) CreateDeviceSession(context.Context, *CreateDeviceSessionRequest) (*DeviceSession, error)
func (UnimplementedDirectAccessServiceServer) GetDeviceSession ¶
func (UnimplementedDirectAccessServiceServer) GetDeviceSession(context.Context, *GetDeviceSessionRequest) (*DeviceSession, error)
func (UnimplementedDirectAccessServiceServer) ListDeviceSessions ¶
func (UnimplementedDirectAccessServiceServer) ListDeviceSessions(context.Context, *ListDeviceSessionsRequest) (*ListDeviceSessionsResponse, error)
func (UnimplementedDirectAccessServiceServer) UpdateDeviceSession ¶
func (UnimplementedDirectAccessServiceServer) UpdateDeviceSession(context.Context, *UpdateDeviceSessionRequest) (*DeviceSession, error)
type UnsafeDirectAccessServiceServer ¶ added in v0.1.1
type UnsafeDirectAccessServiceServer interface {
// contains filtered or unexported methods
}
UnsafeDirectAccessServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to DirectAccessServiceServer will result in compilation errors.
type UpdateDeviceSessionRequest ¶
type UpdateDeviceSessionRequest struct {
// Required. DeviceSession to update.
// The DeviceSession's `name` field is used to identify the session to update
// "projects/{project_id}/deviceSessions/{session_id}"
DeviceSession *DeviceSession `protobuf:"bytes,1,opt,name=device_session,json=deviceSession,proto3" json:"device_session,omitempty"`
// Optional. The list of fields to update.
UpdateMask *fieldmaskpb.FieldMask `protobuf:"bytes,2,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
// contains filtered or unexported fields
}
Request message for DirectAccessService.UpdateDeviceSession.
func (*UpdateDeviceSessionRequest) Descriptor
deprecated
func (*UpdateDeviceSessionRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateDeviceSessionRequest.ProtoReflect.Descriptor instead.
func (*UpdateDeviceSessionRequest) GetDeviceSession ¶
func (x *UpdateDeviceSessionRequest) GetDeviceSession() *DeviceSession
func (*UpdateDeviceSessionRequest) GetUpdateMask ¶
func (x *UpdateDeviceSessionRequest) GetUpdateMask() *fieldmaskpb.FieldMask
func (*UpdateDeviceSessionRequest) ProtoMessage ¶
func (*UpdateDeviceSessionRequest) ProtoMessage()
func (*UpdateDeviceSessionRequest) ProtoReflect ¶
func (x *UpdateDeviceSessionRequest) ProtoReflect() protoreflect.Message
func (*UpdateDeviceSessionRequest) Reset ¶
func (x *UpdateDeviceSessionRequest) Reset()
func (*UpdateDeviceSessionRequest) String ¶
func (x *UpdateDeviceSessionRequest) String() string